#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-retrie-plugin-2.3.0.0-LKKhL0IkXxd4tWxkLvD0y
key:                  hls-retrie-plugin-2.3.0.0-LKKhL0IkXxd4tWxkLvD0y
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  af0040bc4b130bcaa7bc44f27daaa47a
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.3.0.0-LKKhL0IkXxd4tWxkLvD0y
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX ghc-9.6.6
    ghcide-2.3.0.0-F8jFt2FEiLgKgaY5bwOadD
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hls-plugin-api-2.3.0.0-JvSLuDAqDRP3LXV4joMX1
    hls-refactor-plugin-2.3.0.0-CPXTavJM1Mv79ybL6hNS4a
    lens-5.3.5-ApAD4D8hy7K2t3Q7L3bBvG
    lsp-2.2.0.0-IKZ4Mpp9MNAHQA77xxW2p1
    lsp-types-2.0.2.0-1mpQUBvmFx35ELIFe2gyvF mtl-2.3.1
    retrie-1.2.3-JkO7LnZl4WoJyBOG8JH567
    safe-exceptions-0.1.7.4-Ed9tl0V54XFHH60bY3H5co stm-2.5.1.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

